==> client-java-api-3.0.0-sources.jar: io/kubernetes/client/models/V1beta1CustomResourceColumnDefinitionFluentImpl.java <==
package io.kubernetes.client.models;

import java.lang.Integer;
import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

public class V1beta1CustomResourceColumnDefinitionFluentImpl<A extends V1beta1CustomResourceColumnDefinitionFluent<A>> extends io.kubernetes.client.fluent.BaseFluent<A> implements V1beta1CustomResourceColumnDefinitionFluent<A>{

    private String jsONPath;
    private String description;
    private String format;
    private String name;
    private Integer priority;
    private String type;

    public V1beta1CustomResourceColumnDefinitionFluentImpl(){
    }
    public V1beta1CustomResourceColumnDefinitionFluentImpl(V1beta1CustomResourceColumnDefinition instance){
            this.withJsONPath(instance.getJsONPath());

            this.withDescription(instance.getDescription());

            this.withFormat(instance.getFormat());

            this.withName(instance.getName());

            this.withPriority(instance.getPriority());

            this.withType(instance.getType());

    }

    public String getJsONPath(){
            return this.jsONPath;
    }

    public A withJsONPath(String jsONPath){
            this.jsONPath=jsONPath; return (A) this;
    }

    public Boolean hasJsONPath(){
            return this.jsONPath != null;
    }

    public String getDescription(){
            return this.description;
    }

    public A withDescription(String description){
            this.description=description; return (A) this;
    }

    public Boolean hasDescription(){
            return this.description != null;
    }

    public String getFormat(){
            return this.format;
    }

    public A withFormat(String format){
            this.format=format; return (A) this;
    }

    public Boolean hasFormat(){
            return this.format != null;
    }

    public String getName(){
            return this.name;
    }

    public A withName(String name){
            this.name=name; return (A) this;
    }

    public Boolean hasName(){
            return this.name != null;
    }

    public Integer getPriority(){
            return this.priority;
    }

    public A withPriority(Integer priority){
            this.priority=priority; return (A) this;
    }

    public Boolean hasPriority(){
            return this.priority != null;
    }

    public A withNewPriority(int arg1){
            return (A)withPriority(new Integer(arg1));
    }

    public A withNewPriority(String arg1){
            return (A)withPriority(new Integer(arg1));
    }

    public String getType(){
            return this.type;
    }

    public A withType(String type){
            this.type=type; return (A) this;
    }

    public Boolean hasType(){
            return this.type != null;
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            V1beta1CustomResourceColumnDefinitionFluentImpl that = (V1beta1CustomResourceColumnDefinitionFluentImpl) o;
            if (jsONPath != null ? !jsONPath.equals(that.jsONPath) :that.jsONPath != null) return false;
            if (description != null ? !description.equals(that.description) :that.description != null) return false;
            if (format != null ? !format.equals(that.format) :that.format != null) return false;
            if (name != null ? !name.equals(that.name) :that.name != null) return false;
            if (priority != null ? !priority.equals(that.priority) :that.priority != null) return false;
            if (type != null ? !type.equals(that.type) :that.type != null) return false;
            return true;
    }




}

==> client-java-api-5.0.0-sources.jar: io/kubernetes/client/models/V1beta1CustomResourceColumnDefinitionFluentImpl.java <==
package io.kubernetes.client.models;

import java.lang.Integer;
import java.lang.StringBuffer;
import java.lang.StringBuilder;
import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

public class V1beta1CustomResourceColumnDefinitionFluentImpl<A extends V1beta1CustomResourceColumnDefinitionFluent<A>> extends io.kubernetes.client.fluent.BaseFluent<A> implements V1beta1CustomResourceColumnDefinitionFluent<A>{

    private String jsONPath;
    private String description;
    private String format;
    private String name;
    private Integer priority;
    private String type;

    public V1beta1CustomResourceColumnDefinitionFluentImpl(){
    }
    public V1beta1CustomResourceColumnDefinitionFluentImpl(V1beta1CustomResourceColumnDefinition instance){
            this.withJsONPath(instance.getJsONPath());

            this.withDescription(instance.getDescription());

            this.withFormat(instance.getFormat());

            this.withName(instance.getName());

            this.withPriority(instance.getPriority());

            this.withType(instance.getType());

    }

    public String getJsONPath(){
            return this.jsONPath;
    }

    public A withJsONPath(String jsONPath){
            this.jsONPath=jsONPath; return (A) this;
    }

    public Boolean hasJsONPath(){
            return this.jsONPath != null;
    }

    public A withNewJsONPath(String arg1){
            return (A)withJsONPath(new String(arg1));
    }

    public A withNewJsONPath(StringBuilder arg1){
            return (A)withJsONPath(new String(arg1));
    }

    public A withNewJsONPath(StringBuffer arg1){
            return (A)withJsONPath(new String(arg1));
    }

    public String getDescription(){
            return this.description;
    }

    public A withDescription(String description){
            this.description=description; return (A) this;
    }

    public Boolean hasDescription(){
            return this.description != null;
    }

    public A withNewDescription(String arg1){
            return (A)withDescription(new String(arg1));
    }

    public A withNewDescription(StringBuilder arg1){
            return (A)withDescription(new String(arg1));
    }

    public A withNewDescription(StringBuffer arg1){
            return (A)withDescription(new String(arg1));
    }

    public String getFormat(){
            return this.format;
    }

    public A withFormat(String format){
            this.format=format; return (A) this;
    }

    public Boolean hasFormat(){
            return this.format != null;
    }

    public A withNewFormat(String arg1){
            return (A)withFormat(new String(arg1));
    }

    public A withNewFormat(StringBuilder arg1){
            return (A)withFormat(new String(arg1));
    }

    public A withNewFormat(StringBuffer arg1){
            return (A)withFormat(new String(arg1));
    }

    public String getName(){
            return this.name;
    }

    public A withName(String name){
            this.name=name; return (A) this;
    }

    public Boolean hasName(){
            return this.name != null;
    }

    public A withNewName(String arg1){
            return (A)withName(new String(arg1));
    }

    public A withNewName(StringBuilder arg1){
            return (A)withName(new String(arg1));
    }

    public A withNewName(StringBuffer arg1){
            return (A)withName(new String(arg1));
    }

    public Integer getPriority(){
            return this.priority;
    }

    public A withPriority(Integer priority){
            this.priority=priority; return (A) this;
    }

    public Boolean hasPriority(){
            return this.priority != null;
    }

    public String getType(){
            return this.type;
    }

    public A withType(String type){
            this.type=type; return (A) this;
    }

    public Boolean hasType(){
            return this.type != null;
    }

    public A withNewType(String arg1){
            return (A)withType(new String(arg1));
    }

    public A withNewType(StringBuilder arg1){
            return (A)withType(new String(arg1));
    }

    public A withNewType(StringBuffer arg1){
            return (A)withType(new String(arg1));
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            V1beta1CustomResourceColumnDefinitionFluentImpl that = (V1beta1CustomResourceColumnDefinitionFluentImpl) o;
            if (jsONPath != null ? !jsONPath.equals(that.jsONPath) :that.jsONPath != null) return false;
            if (description != null ? !description.equals(that.description) :that.description != null) return false;
            if (format != null ? !format.equals(that.format) :that.format != null) return false;
            if (name != null ? !name.equals(that.name) :that.name != null) return false;
            if (priority != null ? !priority.equals(that.priority) :that.priority != null) return false;
            if (type != null ? !type.equals(that.type) :that.type != null) return false;
            return true;
    }




}
